@@ -713,7 +713,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
     def get_collaborators_for_channel(self, channel_slug):
 
         channel_id = self.get_channel(channel_slug)["id"]
-        url = "{}/smartfeed/channels/{}/users".format(self._base_url, channel_id)
+        url = "/channels/{}/users".format(self._base_url_ch, channel_id)
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
